#!/usr/bin/env python
# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (C) 2011 <Davide Vescovini> <davide.vescovini@gmail.com>
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

######################################################
############# IMPORTAZIONE MODULI ####################
######################################################
# importazione dei moduli necessari
import os
import sys
import datetime
import logging
from pysqlite2 import dbapi2 as sqlite3
######################################################
############# INTERNAZIONALIZZAZIONE #################
######################################################
import gettext
from gettext import gettext as _
gettext.textdomain('metel')
######################################################
########### VARIABILI DA INIZIALIZZARE ###############
######################################################
project_directory = "~/metel"
#nome del listino metel da importare
FileMT = "metel.txt"
# nome del database da creare
FileDB = ":memory:"
# versione
VERSION = "1.1"
# nome del servizio di logging di riferimento
LOGGING = "PreventaLib"

################################################################################
############ GESTIONE ERRORI ###################################################
################################################################################
class MetelError(Exception):
    """Classe per gestire le eccezioni del modulo METEL"""
    def __init__(self, value):
        date = datetime.datetime.now()
        error_info = sys.exc_info()
        self.value = str(date), value, error_info

    def __str__(self):
        return repr(self.value)
################################################################################
############ GESTIONE LOGGING ##################################################
################################################################################
# l'utilizzo del debug è lasciato all'applicazione che usa la libreria
logging.getLogger(LOGGING)
################################################################################
############ LETTURA GESTIONE E IMPORTAZIONE IN UN DATABASE DI UN FILE METEL ###
################################################################################
# una classe per gestire i file metel
class MetelClass:
    """Classe per gestire i dati METEL dei file"""
    def __init__(self, filename=None):
        #contatore delle righe da importare in un file metel
        self.righe_totali = 0 
        #contatore di articoli importati
        self.art_import = 0
        #contatore articoli totali da importare
        self.art_totali = 0 
        #contatore degli errori
        self.err = 0 
        #se nessun file database viene specificato il database viene salvato in memoria
        if filename is None:
            self._FileDB = ":memory:"
        else:
            self.__FileDB = filename
        logging.debug("Database Aperto: %s" % self.__FileDB)
        # inizializza il database
        # Stabilisci la connessione con il database
        self.db = sqlite3.connect(self.__FileDB)
        # imposta l'utilizzo del testo con bytestring
        self.db.text_factory = str
        # inizializza il cursore
        self.c = self.db.cursor()
        # crea le tavole metel
        self.__create_metel_database()

    def __create_metel_database (self):
        """crea il database SQL e le tavole del database"""
        self.c.executescript("""
/* Crea la tavola Metel */
CREATE TABLE IF NOT EXISTS Metel  (id PRIMARY KEY, SiglaMarchio TEXT, CodiceProdAzienda TEXT, DescrizioneProdotto TEXT, 
                                   QuantitaCartone TEXT, QuantitaMulOrdinazione TEXT, QuantitaMinOrdinazione TEXT, 
                                   QuantitaMaxOrdinazione TEXT, LeadTime TEXT, PrezzoRivenditore REAL, PrezzoPubblico REAL, 
                                   MoltiplicatorePrezzo INTEGER, CodiceValuta TEXT, UnitaMisura TEXT, ProdottoComposto TEXT, 
                                   StatoProdotto TEXT, DataUltimaVariazione INTEGER, FamigliaSconto TEXT, FamigliaStatistica TEXT);

/* Crea la tavola degli sconti*/
CREATE TABLE IF NOT EXISTS Sconti (SiglaMarchio PRIMARY KEY, NomeMarchio TEXT, Sconto REAL, Data DATE);

/* Trigger: Inserisce una nuova marca, non presente, viene inserito iun nuovo articolo in Metel*/
CREATE TRIGGER IF NOT EXISTS Insert_SiglaMarchio_Sconti AFTER INSERT ON Metel FOR EACH ROW WHEN new.SiglaMarchio NOT IN (SELECT SiglaMarchio FROM Sconti)
                               BEGIN 
                                 INSERT INTO Sconti VALUES (new.SiglaMarchio, new.SiglaMarchio, 0, CURRENT_TIMESTAMP);
                               END;
/* Trigger: Aggiorna la data della tabella sconti dopo l'aggiornamento della tabella*/
CREATE TRIGGER IF NOT EXISTS Update_data_Sconti AFTER UPDATE OF Sconto, NomeMarchio ON Sconti FOR EACH ROW
                               BEGIN 
                                 UPDATE Sconti SET Data = CURRENT_TIMESTAMP WHERE SiglaMarchio = old.SiglaMarchio;
                               END;
/* Trigger: Cancella una marca non più esistente nella tabella Metel*/
CREATE TRIGGER IF NOT EXISTS Delete_SiglaMarchio_Sconti AFTER DELETE ON Metel FOR EACH ROW
                               BEGIN 
                                 DELETE FROM Sconti WHERE SiglaMarchio NOT IN (SELECT SiglaMarchio FROM Metel);
                               END;""")
        self.db.commit()
        return True

    def connection_shutdown (self):
        """chiude la connessione col database"""
        # Save (commit) the changes to database
        self.db.commit()
        # Chiudiamo il cursore quando abbiamo finito
        self.c.close()
        logging.debug("Database chiuso")
        return True

    def save_database (self):
        """chiude la connessione col database"""
        # Save (commit) the changes to database
        self.db.commit()
        logging.debug("Database salvato")
        return True

    def rollback_database (self):
        """chiude la connessione col database"""
        # Rollback (undo) the changes to database
        self.db.rollback()
        logging.debug("Modifiche al DB annullate dall'ultimo salvataggio")
        return True

    def delete_metel_database (self):
        """cancella tutti gli articoli dal database e ricrea le tavole"""
        try:
             # cancella le tavole esistenti
             self.c.execute("""DROP TABLE Metel""")
             self.c.execute("""DROP TABLE Sconti""")
             self.__create_metel_database()
        except:
             raise MetelError("Errore, eliminare gli articoli da database, le tavole inesistenti o File database inesistente")
        finally:
             logging.debug(_("Cancellazione di tutte le tavole del Database"))
             self.db.commit()
             return

    def import_line (self, stringa):
        """importa una stringa e la suddivide nei singoli campi secondo le specifiche METEL"""
        articolo = create_metel_from_string(stringa)
        # conversione e rinormalizzazione di alcuni campi in decimali
        articolo.MoltiplicatorePrezzo = converte_intero (articolo.MoltiplicatorePrezzo)
        articolo.DataUltimaVariazione = converte_intero (articolo.DataUltimaVariazione)
        articolo.PrezzoRivenditore = converte_prezzo (articolo.PrezzoRivenditore, articolo.MoltiplicatorePrezzo)
        articolo.PrezzoPubblico = converte_prezzo (articolo.PrezzoPubblico, articolo.MoltiplicatorePrezzo)
        # crea il rigo da inserire in database concatenando i campi in una lista
        row = articolo.row()
        # Insert a row of data or report an error
        try:
            self.c.executemany("""INSERT INTO Metel VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)""", row)
            # Contatore di articoli importati
            self.art_import += 1
            logging.debug("Articoli importati: %d/%d" % (self.art_import, self.art_totali)) 
        except:
            self.err += 1
            raise MetelError("Errore nell'importazione di questo articolo: \n %s \n" % row)
        finally:
            logging.debug(_("Articolo con Primary key: %s") % str(articolo.id ))
            return True

    def import_file (self, FileMetel):
        """funzione per apertura e lettura dei file METEL e importazione in un database SQL"""
        #Apre il file e importa le singole righe
        metel_rows = self.read_metel_file(FileMetel)
        #Inizializza i contatore di articoli importati e degli errori di importazione
        self.art_totali = len(metel_rows)
        self.art_import = 0
        self.err = 0
        # per ogni riga di dati del file sorgente inserisce una riga all'interno del database
        for line in metel_rows:
            # Insert a row of data or report an error
            row = self.import_line (line)
        # Messaggi di DEBUG con linee importate e errori riscontrati
        logging.debug("Importazione file METEL nel database conclusa, %d articoli importati." % self.art_import)
        if self.err > 0:
            logging.warn(_("Trovati %d articoli con errori non importati.") % self.err)
        return (self.art_import + self.err)


    def conta_articoli_file (self, FileMT):
        """funzione per contare il numero di articoli dei file METEL"""
        # Apriamo il file TXT in sola lettura
        FileMetel = file(FileMT,"r")
        lista = FileMetel.readlines()
        # chiudiamo il file
        FileMetel.close()
        return len(lista)

    def read_metel_file (self, FileMT):
        """funzione per apertura e lettura dei file METEL"""
        # Apriamo il file TXT in sola lettura
        FileMetel = file(FileMT,"r")
        lista = FileMetel.readlines()
        FileMetel.close()
        return lista
################################################################################
# RICERCA ESTRAZIONE DATI ######################################################
################################################################################
    def extract_data (self, istruzione_sql, target):
        """Esegue un'istruzione SQL sul database e esporta i risultati su un file di log"""
        # trasforma i dati di ingresso del database in una tupla per prevenire problemi di sicurezza (SQL injection)    
        t = (target,)
        try:
            # eseguiamo l'istruzione SQL
            self.c.execute(istruzione_sql + """ ?""", t)
            Fail = False
            # selezioniamo l'output e stampiamo sul terminale
            for row in self.c:
                print row
        except:  
            raise MetelError("Errore di esecuzione istruzione SQL: %s %s \n" % (istruzione_sql, t[0]))
            Fail = True
        finally:
            return Fail

    def extract_metel_rows (self):
        """Estrae tutte le righe dal database Metel"""
        self.c.execute("""SELECT * FROM Metel ORDER BY SiglaMarchio""")
        lista = self.c.fetchall()
        return lista

    def extract_marche_metel (self):
        """Estrae dal database Metel le Marche presenti"""
        self.c.execute("""SELECT SiglaMarchio FROM Metel""")
        lista = set(self.c.fetchall())
        lista_marche = list()
        for marca in lista:
            lista_marche.append(marca[0])
        return lista_marche

    def extract_sconti_rows (self):
        """Estrae tutte le righe dalla tabella Sconti del Database"""
        # Memorizza tutte le righe in una lista
        self.c.execute("""SELECT * FROM Sconti""")
        lista = self.c.fetchall()
        return lista

    def get_sconto_marca (self, marca):
        """Estrae tutte le righe dalla tabella Sconti del Database"""
        self.c.execute("""SELECT Sconto FROM Sconti WHERE SiglaMarchio=:marca """, {"marca":marca})
        sconto = self.c.fetchall()
        if len(sconto)>0: sconto = sconto[0][0]
        else: sconto = None
        return sconto

    def search_rows (self, listino=None, list_columns='*', 
                     search_column=None, search_key=' ', 
                     order='CodiceProdAzienda',
                     default_column=True):
        """Esegue un'istruzione SQL di ricerca estrazione sul database"""
        lista = list()
        # se il listino è nullo ricerca in tutto il database
        if listino is None:
            listino = """1=1"""
        else: 
            listino = "SiglaMarchio='{0}'".format(listino)
        # parametro colonne da esterre dal database
        if list_columns is None and default_column:
            column = """SiglaMarchio, CodiceProdAzienda, DescrizioneProdotto, CodiceValuta, UnitaMisura, PrezzoPubblico, DataUltimaVariazione"""
        elif list_columns is None: 
            column='*'
        else:
            column = list_columns
        # paraetro colonna di ricerca
        if search_column is None: 
            search='1=1'
        else: 
            search = "{0} LIKE '%{1}%'".format(search_column, search_key)
        # ricerca nel database
        try:
            self.c.execute("""SELECT {0} FROM Metel WHERE {1} AND {2} ORDER BY {3};""".format(
                          column, listino, search, order))
        except: 
            raise MetelError("Errore di esecuzione istruzione SELECT in search_rows()")
        finally:
            # recuperiamo la lista delle righe selezionate
            lista = self.c.fetchall()
            return lista

################################################################################
# INSERIMENTO CANCELLAZIONE E AGGIORNAMENTO ARTICOLI ###########################
################################################################################
    def insert_art (self, articolo):
        """Inserisce un nuovo articolo nel database"""
        # crea il rigo da inserire in database concatenando i campi in una lista
        row = articolo.row()
        # Insert a row of data or report an error
        try:
            self.c.executemany("""INSERT INTO Metel VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)""", row)
            # Contatore di articoli importati
        except:
            raise MetelError(_("Errore nell'inserimento dell'articolo nel database: \n %s \n") % str(articolo))
        finally:
            logging.debug(_("Articolo inserito con Primary key: %s") % str(articolo.id))
            return True

    def delete_row (self, primary_key):
        """Cancella un rigo specifico dal database utilizzando la sua PRIMARY KEY"""
        # eseguiamo l'istruzione SQL per cancellare il rigo dal db
        istruzione = """DELETE FROM Metel WHERE id = '%s'""" % (primary_key)
        try:
            # eseguiamo l'istruzione SQL di cancellazione
            self.c.execute(istruzione)
            logging.debug(_("Articolo '%s' cancellato dal database") % primary_key)
        except: 
            raise MetelError(_("Errore di esecuzione istruzione SQL: %s \n") % istruzione)
        finally:
            logging.debug(_("Articolo cancellato con Primary key: %s") % primary_key)
            return True

    def delete_listino (self, listino):
        """Cancella un Listino dal database utilizzando il nome ('SiglaMarchio')"""
        # eseguiamo l'istruzione SQL per cancellare tutte le righe con listino dal db
        istruzione = """DELETE FROM Metel WHERE SiglaMarchio = '%s'""" % (listino)
        try:
            # eseguiamo l'istruzione SQL di cancellazione
            self.c.execute(istruzione)
        except: 
            raise MetelError(_("Errore di cancellazione listino: %s") % listino)
        finally:
            logging.debug(_("Listino '%s' cancellato dal database") % listino)
            return True

    def update_sconti_rows (self, sigla, nome, sconto):
        """Aggiorna un rigo della tabella sconti"""
        try:
            self.c.execute("""UPDATE Sconti SET NomeMarchio=:nome, Sconto=:sconto  WHERE SiglaMarchio=:sigla;""", 
                          {"sigla":sigla, "nome":nome, "sconto":sconto})
            update = True
        except: 
            raise MetelError(_("Errore di aggiornamento della tabella 'Sconti':  %s") % sigla)
            update = False
        finally:
            logging.debug(_("Tabella 'Sconti' %s aggiornata") % sigla)
            self.db.commit()
            return update

    def delete_sconti_row (self, sigla):
        """Aggiorna un rigo della tabella sconti"""
        try:
            self.c.execute("""DELETE FROM Sconti WHERE SiglaMarchio=:sigla;""", {"sigla":sigla})
            update = True
        except: 
            raise MetelError(_("Errore di cancellazione della marca %s dalla tabella Sconti") % sigla)
            update = False
        finally:
            logging.debug(_("Marca %s cancellata dalla tabella 'Sconti'") % sigla)
            self.db.commit()
            return update

################################################################################
############ CREAZIONE DI ARTICOLI METEL #######################################
################################################################################
# una classe per gestire i file metel
class ArticoloMetel:
    """Classe per gestire i dati METEL dei file"""
    def __init__(self, SiglaMarchio = None, 
                       CodiceProdAzienda = None, 
                       CodiceValuta = 'EUR',
                       CodiceEAN = '0000000000000',
                       DescrizioneProdotto = str(), 
                       QuantitaCartone = '00001',
                       QuantitaMulOrdinazione = '00001', 
                       QuantitaMinOrdinazione = '00001',
                       QuantitaMaxOrdinazione = '999999', 
                       LeadTime = 'D', 
                       PrezzoRivenditore = int(), 
                       PrezzoPubblico = int(),
                       MoltiplicatorePrezzo = int(), 
                       UnitaMisura = 'PCE',
                       ProdottoComposto = '0', 
                       StatoProdotto = '1',
                       DataUltimaVariazione = None, 
                       FamigliaSconto = str(),
                       FamigliaStatistica = str()):
        if SiglaMarchio is None:
            self.SiglaMarchio = str()
        else: self.SiglaMarchio = str(SiglaMarchio)
        if CodiceProdAzienda is None:
            self.CodiceProdAzienda = str()
        else: self.CodiceProdAzienda = str(CodiceProdAzienda)
        self.CodiceEAN = CodiceEAN
        self.DescrizioneProdotto = str(DescrizioneProdotto)
        self.QuantitaCartone = QuantitaCartone
        self.QuantitaMulOrdinazione = QuantitaMulOrdinazione
        self.QuantitaMinOrdinazione = QuantitaMinOrdinazione
        self.QuantitaMaxOrdinazione = QuantitaMaxOrdinazione
        self.LeadTime = LeadTime
        self.PrezzoRivenditore = int(PrezzoRivenditore)
        self.PrezzoPubblico = int(PrezzoPubblico)
        self.MoltiplicatorePrezzo = int(MoltiplicatorePrezzo)
        if CodiceValuta is None:
            self.CodiceValuta = 'EUR'
        else: self.CodiceValuta = CodiceValuta
        self.UnitaMisura = str(UnitaMisura)
        self.ProdottoComposto = str(ProdottoComposto)
        self.StatoProdotto = str(StatoProdotto)
        if DataUltimaVariazione is None:
            # imposta la data attuale nel campo data
            data = "{0:%Y%m%d}".format(datetime.datetime.now())
            self.DataUltimaVariazione = data
        else:
            self.DataUltimaVariazione = str(DataUltimaVariazione)
        self.FamigliaSconto = str(FamigliaSconto)
        self.FamigliaStatistica = str(FamigliaStatistica)
        # componi la 'primary key' per l'inserimeto nel database
        self.id = self.SiglaMarchio + self.CodiceProdAzienda + self.CodiceValuta

    def row(self):
        # crea il rigo da inserire in database concatenando i campi in una lista
        row = [(self.id, self.SiglaMarchio, self.CodiceProdAzienda, 
                self.DescrizioneProdotto, self.QuantitaCartone, 
                self.QuantitaMulOrdinazione, self.QuantitaMinOrdinazione, 
                self.QuantitaMaxOrdinazione, self.LeadTime, self.PrezzoRivenditore, 
                self.PrezzoPubblico, self.MoltiplicatorePrezzo, self.CodiceValuta, 
                self.UnitaMisura, self.ProdottoComposto, self.StatoProdotto, 
                self.DataUltimaVariazione, self.FamigliaSconto, 
                self.FamigliaStatistica)]
        return row

    def key(self):
        """restituisce la stringa tilizzabile come chiave univoca dell'articolo MEtel"""
        return self.SiglaMarchio + self.CodiceProdAzienda + self.CodiceValuta

    def convert_to_string(self):
        # trasforma i campi in stringhe e ne verifica la lunghezza
        cr = "/r/n"
        s1 = str(self.SiglaMarchio)
        if len(s1) < 3:
            s1 = s1[:3] + " " * (3 - len(s1))
        s2 = str(self.CodiceProdAzienda)
        if len(s2) < 16:
            s2 = s2[:16] + " " * (16 - len(s2))
        s3 = str(self.CodiceEAN)
        if len(s3) < 13:
            s3 = s3[:13] + " " * (13 - len(s3))
        s4 = str(self.DescrizioneProdotto)
        if len(s4) < 43:
            s4 = s4[:43] + " " * (43 - len(s4))
        s5 = str(self.QuantitaCartone)
        if len(s5) < 5:
            s5 = "0" * (5 - len(s5)) + s5[:5]
        s6 = str(self.QuantitaMulOrdinazione)
        if len(s6) < 5:
            s6 = "0" * (5 - len(s6)) + s6[:5]
        s7 = str(self.QuantitaMinOrdinazione)
        if len(s7) < 5:
            s7 = "0" * (5 - len(s7)) + s7[:5]
        s8 = str(self.QuantitaMaxOrdinazione)
        if len(s8) < 6:
            s8 = "0" * (6 - len(s8)) + s8[:6]
        s9 = str(self.LeadTime)
        if len(s9) < 1:
            s9 = s9[:1] + "0" * (1 - len(s9))
        s10 = str(self.PrezzoRivenditore)
        if len(s10) < 11:
            s10 = "0" * (11 - len(s10)) + s10[:11]
        s11 = str(self.PrezzoPubblico)
        if len(s11) < 11:
            s11 = "0" * (11 - len(s11)) + s11[:11]
        s12 = str(self.MoltiplicatorePrezzo)
        if len(s12) < 6:
            s12 = "0" * (6 - len(s12)) + s12[:6]
        s13 = str(self.CodiceValuta)
        if len(s13) < 3:
            s13 = s13[:3] + " " * (3 - len(s13))
        s14 = str(self.UnitaMisura)
        if len(s14) < 3:
            s14 = s14[:3] + " " * (3 - len(s14))
        s15 = str(self.ProdottoComposto)
        if len(s15) < 1:
            s15 = s15[:1] + " " * (1 - len(s15))
        s16 = str(self.StatoProdotto)
        if len(s16) < 1:
            s16 = s16[:1] + " " * (1 - len(s16))
        s17 = str(self.DataUltimaVariazione)
        if len(s17) < 8:
            s17 = s17[:8] + " " * (8 - len(s17))
        s18 = str(self.FamigliaSconto)
        if len(s18) < 18:
            s18 = s18[:18] + " " * (18 - len(s18))
        s19 = str(self.FamigliaStatistica)
        if len(s19) < 18:
            s19 = s19[:18] + " " * (18 - len(s19))
        return s1+s2+s3+s4+s5+s6+s7+s8+s9+s10+s11+s12+s13+s14+s15+s16+s17+s18+s19+cr

    def __str__(self):
        return self.convert_to_string()

#######################################################
# funzione per creare un articolo metel da una stringa
def create_metel_from_string (stringa):
    """importa una stringa e la suddivide nei singoli campi secondo le specifiche METEL"""
    if len(stringa) < 177:
        logging.warn("Errore la stringa da convertire in articolo Metel non ha 177 caratteri, l'articolo sarà incompleto: '%s'" % stringa)
    articolo = ArticoloMetel()
    articolo.SiglaMarchio = stringa[0:3]
    articolo.CodiceProdAzienda = stringa[3:19]
    articolo.CodiceEAN = stringa[19:32]
    articolo.DescrizioneProdotto = stringa[32:75]
    articolo.QuantitaCartone = stringa[75:80]
    articolo.QuantitaMulOrdinazione = stringa[80:85]
    articolo.QuantitaMinOrdinazione = stringa[85:90]
    articolo.QuantitaMaxOrdinazione = stringa[90:96]
    articolo.LeadTime = stringa[96:97]
    articolo.PrezzoRivenditore = stringa[97:108]
    articolo.PrezzoPubblico = stringa[108:119]
    articolo.MoltiplicatorePrezzo = stringa[119:125]
    articolo.CodiceValuta = stringa[125:128]
    articolo.UnitaMisura = stringa[128:131]
    articolo.ProdottoComposto = stringa[131:132]
    articolo.StatoProdotto = stringa[132:133]
    articolo.DataUltimaVariazione = stringa[133:141]
    articolo.FamigliaSconto = stringa[141:159]
    articolo.FamigliaStatistica = stringa[159:]
    articolo.id = articolo.SiglaMarchio + articolo.CodiceProdAzienda + articolo.CodiceValuta
    return articolo

def converte_prezzo (prezzo, moltiplicatore):
        """trasforma un campo prezzo METEL in un valore decimale a virgola mobile"""
        # verifica se il prezzo è convertibile da stringa a intero
        try:           
            prezzo = float(prezzo)
        except:
            prezzo = 0
        # verifica se il moltiplicatore è convertibile da stringa a intero
        try:           
            moltiplicatore = int(moltiplicatore)
        except:
            moltiplicatore = 1
        # esegue il calcolo del prezzo secondo le specifiche metel
        valore = (prezzo)/(100*moltiplicatore)
        return valore

def converte_intero (valore):
        """trasforma un campo testo METEL in un valore intero"""
        # verifica se il prezzo è convertibile da stringa a intero
        try:           
            valore = int(valore)
        except:
            valore = 1
        return valore
################################################################################
###################### TEST ####################################################
################################################################################

def test():
    """Funzione di test della libreria metel SQL"""
    print "Inizio Test"
    DatiMetel = MetelClass(FileDB)
    DatiMetel.import_file (FileMT)
    DatiMetel.extract_data ("""SELECT * FROM Metel ORDER BY""", """DataUltimaVariazione""")
    print "End Test"

if __name__ == "__main__":
    test()
